==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/scom/kotlin/inputs/DomainControllerPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.scom.kotlin.inputs

import com.pulumi.azurenative.scom.inputs.DomainControllerPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The properties of domain controller to which SCOM and SQL servers join for AuthN/AuthZ.
 * @property dnsServer IP address of DNS server
 * @property domainName Fully qualified domain name
 * @property ouPath Organizational Unit path in which the SCOM servers will be present
 */
public data class DomainControllerPropertiesArgs(
    public val dnsServer: Output<String>? = null,
    public val domainName: Output<String>? = null,
    public val ouPath: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.scom.inputs.DomainControllerPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.scom.inputs.DomainControllerPropertiesArgs =
        com.pulumi.azurenative.scom.inputs.DomainControllerPropertiesArgs.builder()
            .dnsServer(dnsServer?.applyValue({ args0 -> args0 }))
            .domainName(domainName?.applyValue({ args0 -> args0 }))
            .ouPath(ouPath?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DomainControllerPropertiesArgs].
 */
@PulumiTagMarker
public class DomainControllerPropertiesArgsBuilder internal constructor() {
    private var dnsServer: Output<String>? = null

    private var domainName: Output<String>? = null

    private var ouPath: Output<String>? = null

    /**
     * @param value IP address of DNS server
     */
    @JvmName("ihqxlkiepqqalfqy")
    public suspend fun dnsServer(`value`: Output<String>) {
        this.dnsServer = value
    }

    /**
     * @param value Fully qualified domain name
     */
    @JvmName("ntmspnkfelhttjgg")
    public suspend fun domainName(`value`: Output<String>) {
        this.domainName = value
    }

    /**
     * @param value Organizational Unit path in which the SCOM servers will be present
     */
    @JvmName("ffqronvdxxlwvycl")
    public suspend fun ouPath(`value`: Output<String>) {
        this.ouPath = value
    }

    /**
     * @param value IP address of DNS server
     */
    @JvmName("jnxanpqisraelopk")
    public suspend fun dnsServer(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dnsServer = mapped
    }

    /**
     * @param value Fully qualified domain name
     */
    @JvmName("sttnctxtrkorqhrm")
    public suspend fun domainName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.domainName = mapped
    }

    /**
     * @param value Organizational Unit path in which the SCOM servers will be present
     */
    @JvmName("psygwvapqdtvovwm")
    public suspend fun ouPath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ouPath = mapped
    }

    internal fun build(): DomainControllerPropertiesArgs = DomainControllerPropertiesArgs(
        dnsServer = dnsServer,
        domainName = domainName,
        ouPath = ouPath,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/scom/kotlin/inputs/DomainControllerPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.scom.kotlin.inputs

import com.pulumi.azurenative.scom.inputs.DomainControllerPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The properties of domain controller to which SCOM and SQL servers join for AuthN/AuthZ.
 * @property dnsServer IP address of DNS server
 * @property domainName Fully qualified domain name
 * @property ouPath Organizational Unit path in which the SCOM servers will be present
 */
public data class DomainControllerPropertiesArgs(
    public val dnsServer: Output<String>? = null,
    public val domainName: Output<String>? = null,
    public val ouPath: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.scom.inputs.DomainControllerPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.scom.inputs.DomainControllerPropertiesArgs =
        com.pulumi.azurenative.scom.inputs.DomainControllerPropertiesArgs.builder()
            .dnsServer(dnsServer?.applyValue({ args0 -> args0 }))
            .domainName(domainName?.applyValue({ args0 -> args0 }))
            .ouPath(ouPath?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DomainControllerPropertiesArgs].
 */
@PulumiTagMarker
public class DomainControllerPropertiesArgsBuilder internal constructor() {
    private var dnsServer: Output<String>? = null

    private var domainName: Output<String>? = null

    private var ouPath: Output<String>? = null

    /**
     * @param value IP address of DNS server
     */
    @JvmName("tiugvqqfbaejgkvg")
    public suspend fun dnsServer(`value`: Output<String>) {
        this.dnsServer = value
    }

    /**
     * @param value Fully qualified domain name
     */
    @JvmName("oygodhdpudhgdlrp")
    public suspend fun domainName(`value`: Output<String>) {
        this.domainName = value
    }

    /**
     * @param value Organizational Unit path in which the SCOM servers will be present
     */
    @JvmName("vujfavoqgjykjcek")
    public suspend fun ouPath(`value`: Output<String>) {
        this.ouPath = value
    }

    /**
     * @param value IP address of DNS server
     */
    @JvmName("smnskshdouslnhfh")
    public suspend fun dnsServer(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dnsServer = mapped
    }

    /**
     * @param value Fully qualified domain name
     */
    @JvmName("oicyhkjblvnhtixc")
    public suspend fun domainName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.domainName = mapped
    }

    /**
     * @param value Organizational Unit path in which the SCOM servers will be present
     */
    @JvmName("ayboxrwuwnwgybij")
    public suspend fun ouPath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ouPath = mapped
    }

    internal fun build(): DomainControllerPropertiesArgs = DomainControllerPropertiesArgs(
        dnsServer = dnsServer,
        domainName = domainName,
        ouPath = ouPath,
    )
}
